Module tokenizer
cpd_
tokenizer
0.1.5
Module tokenizer
Module Items
Structs
Enums
Functions
In crate cpd_
tokenizer
cpd_tokenizer
Module
tokenizer
Structs

Token
Map
A sub-format detection map produced by multi-format tokenizers.
Tokenize
Options
Options for the detection-path tokenizer.
Enums

Mode
Functions

code_
ignore_
ranges
Compute byte ranges of all regex matches against source text. Used to populate
ignore_ranges
from
ignorePattern
regexes before tokenization, matching v4 semantics where regex patterns match against source text regions (not individual token values).
push_
token
Push a token into the detection output if it passes all filters.
tokenize
Tokenize source code in the given format with the given mode. Returns a Vec
. Never panics on empty input — returns empty Vec.
tokenize_
to_
detection
Tokenize source code for the detection hot path.
tokenize_
to_
detection_
maps
Tokenize source code into one or more format-specific detection maps.